=======
Credits
=======

Development Lead
----------------

* Roy Hooper <rhooper@toybox.ca>

Contributors
------------

None yet. Why not be the first?


Acknowledgements
----------------
This module is adapted from django-timer by Iacopo Spalletti <i.spalletti@nephila.it> at
https://github.com/nephila/djangocms-timer

